<?php

namespace Laraecart\Option\Policies;

use Litepie\User\Contracts\UserPolicy;
use Laraecart\Option\Models\Option;

class OptionPolicy
{

    /**
     * Determine if the given user can view the option.
     *
     * @param UserPolicy $user
     * @param Option $option
     *
     * @return bool
     */
    public function view(UserPolicy $user, Option $option)
    {
        if ($user->canDo('option.option.view') && $user->isAdmin()) {
            return true;
        }

        return $option->user_id == user_id() && $option->user_type == user_type();
    }

    /**
     * Determine if the given user can create a option.
     *
     * @param UserPolicy $user
     * @param Option $option
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('option.option.create');
    }

    /**
     * Determine if the given user can update the given option.
     *
     * @param UserPolicy $user
     * @param Option $option
     *
     * @return bool
     */
    public function update(UserPolicy $user, Option $option)
    {
        if ($user->canDo('option.option.edit') && $user->isAdmin()) {
            return true;
        }

        return $option->user_id == user_id() && $option->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given option.
     *
     * @param UserPolicy $user
     * @param Option $option
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Option $option)
    {
        return $option->user_id == user_id() && $option->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given option.
     *
     * @param UserPolicy $user
     * @param Option $option
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Option $option)
    {
        if ($user->canDo('option.option.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given option.
     *
     * @param UserPolicy $user
     * @param Option $option
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Option $option)
    {
        if ($user->canDo('option.option.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
